@@ -1,3 +1,3 @@
 from .testmachine import TestMachine
 
-__all__ = ('TestMachine')
+__all__ = ['TestMachine']
